Struct Enum
pub struct Enum { /* private fields */ }Expand description
This structure represents an editable enum type (DW_TAG_enumeration_type)
Implementations
impl Enum
impl Enum
pub fn set_size(&mut self, size: u64)
pub fn set_size(&mut self, size: u64)
Define the number of bytes required to hold an instance of the
enumeration (DW_AT_byte_size).
pub fn add_value(&mut self, name: &str, value: i64) -> Value
pub fn add_value(&mut self, name: &str, value: i64) -> Value
Add an enum value by specifying its name and its integer value
pub fn set_underlying_type(&mut self, ty: &dyn EditorType) -> &mut Self
pub fn set_underlying_type(&mut self, ty: &dyn EditorType) -> &mut Self
Set the underlying type that is used to encode this enum