Enum lief::elf::SecInsertPos
pub enum SecInsertPos {
AUTO,
POST_SEGMENT,
POST_SECTION,
UNKNOWN(u32),
}Expand description
Strategy for inserting a new section
Variants
AUTO
Let LIEF choose the best strategy
POST_SEGMENT
Insert after the last segment offset, before debug info
POST_SECTION
Insert after the last section offset, at binary end
UNKNOWN(u32)