Struct lief::logging::Scoped

pub struct Scoped { /* private fields */ }
RAII-like scoped log level.

use lief::logging;

logging::set_level(logging::Level::INFO);

{
    let _scoped = logging::Scoped::new(logging::Level::DEBUG);
    // Log level is now DEBUG
}
// Log level is restored to INFO

Implementations



impl Scoped

pub fn new(level: Level) -> Self

Create a new scoped log level. The current log level is saved and replaced with the provided level. When this value is dropped, the original level is restored.

pub fn set_level(&self, level: Level)

Change the log level within this scope

pub fn reset(&mut self)

Reset the log level to the value it had before this scope was created