lief::macho::commands::function_variant_fixups

Struct Fixup

pub struct Fixup<'a> { /* private fields */ }
A single relocation associated with a function-variant. It mirrors the FunctionVariantFixups::InternalFixup structure used by dyld and describes a slot that must be fixed up to point to the variant referenced by Fixup::variant_index.

Implementations



impl Fixup<'_>

pub fn seg_offset(&self) -> u32

Offset of the slot to fix up, relative to the segment designated by Fixup::seg_index

pub fn seg_index(&self) -> u32

Index of the segment that owns the slot to fix up

pub fn variant_index(&self) -> u32

Index of the FunctionVariants runtime table used to resolve the slot

pub fn pac_auth(&self) -> bool

Whether the slot is signed with pointer authentication (arm64e)

pub fn pac_address(&self) -> bool

Whether the pointer-authentication signature mixes the storage address (address diversity)

pub fn pac_key(&self) -> u8

Pointer-authentication key used to sign the slot

pub fn pac_diversity(&self) -> u16

Pointer-authentication diversity (discriminator) of the slot

pub fn segment(&self) -> Option<Segment<'_>>

Segment referenced by Fixup::seg_index if it could be resolved