Struct lief::macho::ParserConfig

pub struct ParserConfig {
    pub parse_dyld_exports: bool,
    pub parse_dyld_bindings: bool,
    pub parse_dyld_rebases: bool,
    pub parse_overlay: bool,
    pub fix_from_memory: bool,
    pub from_dyld_shared_cache: bool,
}
This structure is used to tweak the MachO parser: crate::macho::FatBinary::parse_with_config

Fields

parse_dyld_exports: bool

Parse the Dyld export trie

parse_dyld_bindings: bool

Parse the Dyld binding opcodes

parse_dyld_rebases: bool

Parse the Dyld rebase opcodes

parse_overlay: bool

Whether the overlay data should be parsed

fix_from_memory: bool

When parsing Mach-O from memory, this option can be used to undo relocations and symbols bindings.

When activated, this option requires parse_dyld_bindings and parse_dyld_rebases to be enabled.

from_dyld_shared_cache: bool

Whether the binary is coming/extracted from Dyld shared cache

Implementations



impl Config

pub fn deep() -> Self

Configuration that parses all supported MachO structures (deep parse).

pub fn quick() -> Self

Configuration for a quick parse of the most important MachO structures.