pub enum Type {
UNDEFINED,
ABSOLUTE_SYM,
SECTION,
PREBOUND,
INDIRECT,
UNKNOWN(u32),
}Expand description
Symbol type as defined by nlist_xx.n_type & N_TYPE
Variants
UNDEFINED
The symbol is undefined
ABSOLUTE_SYM
The symbol is absolute
SECTION
The symbol is defined in a specific section
PREBOUND
The symbol is undefined and the image is using a prebound value
INDIRECT
The symbol is defined to be the same as another symbol
UNKNOWN(u32)