pub struct ThreadLocalVariables<'a> { /* private fields */ }
This class represents a MachO section whose type is crate::macho::section::Type::THREAD_LOCAL_VARIABLES.

It contains an array of thread-local variable descriptors (Thunk) used by dyld to lazily initialize thread-local storage on first access.

Implementations



impl ThreadLocalVariables<'_>

pub fn nb_thunks(&self) -> u64

Number of Thunk descriptors in this section

pub fn thunks(&self) -> Thunks<'_>

Iterator over the Thunk descriptors stored in this section

pub fn get(&self, idx: u64) -> Option<Thunk<'_>>

Return the Thunk at the given index, or None if out of range.

pub fn set(&mut self, idx: u64, thunk: &Thunk<'_>)

Change the Thunk at the given index.