lief::objc::category

Struct Category

pub struct Category<'a> { /* private fields */ }
This class represents an Objective-C category (e.g. @interface NSString (MyAdditions))

Implementations



impl Category<'_>

pub fn name(&self) -> String

Name of the category

pub fn class_name(&self) -> String

(demangled) name of the class extended by this category

pub fn methods(&self) -> Methods<'_>

Iterator over the different Method defined by this category

pub fn protocols(&self) -> Protocols<'_>

Iterator over the different Protocol adopted by this category

pub fn properties(&self) -> Properties<'_>

Iterator over the Property of this category

pub fn to_decl(&self) -> String

Generate a header-like string for this specific category

pub fn to_decl_with_opt(&self, opt: &DeclOpt) -> String

Same behavior as Category::to_decl but with an additional DeclOpt parameter to customize the output