Trait AsDynamicRelocation
pub trait AsDynamicRelocation {
// Provided methods
fn version(&self) -> u32 { ... }
fn symbol(&self) -> u64 { ... }
fn fixups(&self) -> Option<DynamicFixup<'_>> { ... }
}Expand description
Trait shared by all dynamic relocations
Provided Methods
fn symbol(&self) -> u64
fn symbol(&self) -> u64
Symbol address. Some values have a special meaning and define how fixups are encoded
fn fixups(&self) -> Option<DynamicFixup<'_>>
fn fixups(&self) -> Option<DynamicFixup<'_>>
Return fixups information, where the interpretation may depend on the
AsDynamicRelocation::symbol