parse_from_dump

Function parse_from_dump 

pub fn parse_from_dump<P: AsRef<Path>>(path: P, addr: u64) -> Option<Binary>
Parse the PE binary from a memory dump located at path that was mapped at the virtual address addr