pub struct FixedFileInfo {
Show 13 fields pub signature: u32, pub struct_version: u32, pub file_version_ms: u32, pub file_version_ls: u32, pub product_version_ms: u32, pub product_version_ls: u32, pub file_flags_mask: u32, pub file_flags: u32, pub file_os: u32, pub file_type: u32, pub file_subtype: u32, pub file_date_ms: u32, pub file_date_ls: u32,
}
Represents fixed file information from a version resource

Fields

signature: u32

Contains the value 0xFEEF04BD. This is used with the szKey member of the VS_VERSIONINFO structure when searching a file for the VS_FIXEDFILEINFO structure.

struct_version: u32

The binary version number of this structure. The high-order word of this member contains the major version number, and the low-order word contains the minor version number.

file_version_ms: u32

The most significant 32 bits of the file’s binary version number. This member is used with file_version_ls to form a 64-bit value used for numeric comparisons.

file_version_ls: u32

The least significant 32 bits of the file’s binary version number. This member is used with file_version_ms to form a 64-bit value used for numeric comparisons.

product_version_ms: u32

The most significant 32 bits of the binary version number of the product with which this file was distributed. This member is used with product_version_ls to form a 64-bit value used for numeric comparisons.

product_version_ls: u32

The least significant 32 bits of the binary version number of the product with which this file was distributed. This member is used with product_version_ms to form a 64-bit value used for numeric comparisons.

file_flags_mask: u32

Contains a bitmask that specifies the valid bits in file_flags. A bit is valid only if it was defined when the file was created.

file_flags: u32

Contains a bitmask that specifies the Boolean attributes of the file. This member can include one or more of the values specified in FILE_FLAGS

file_os: u32

The operating system for which this file was designed. This member can be one of the values specified in VERSION_OS.

file_type: u32

The general type of file. This member can be one of the values specified in FILE_TYPE. All other values are reserved.

file_subtype: u32

The function of the file. The possible values depend on the value of file_type.

file_date_ms: u32

The most significant 32 bits of the file’s 64-bit binary creation date and time stamp.

file_date_ls: u32

The least significant 32 bits of the file’s 64-bit binary creation date and time stamp.