Struct lief::pe::rich_header::RichHeader
pub struct RichHeader<'a> { /* private fields */ }Expand description
Structure which represents the not-so-documented rich header
This structure is usually located at the end of the crate::pe::Binary::dos_stub
and contains information about the build environment.
It is generated by the Microsoft linker link.exe and there are no options to disable
or remove this information.
Implementations
impl<'a> RichHeader<'a>
impl<'a> RichHeader<'a>
pub fn raw_with_key(&self, xor_key: u32) -> Vec<u8>
pub fn raw_with_key(&self, xor_key: u32) -> Vec<u8>
Return the raw bytes of the Rich header XOR-ed with the given key