Struct lief::pe::ParserConfig
pub struct ParserConfig {
pub parse_signature: bool,
pub parse_exports: bool,
pub parse_imports: bool,
pub parse_rsrc: bool,
pub parse_reloc: bool,
pub parse_exceptions: bool,
pub parse_arm64x_binary: bool,
}Expand description
This structure is used to configure the behavior of the PE Parser: crate::pe::Binary::parse_with_config
Fields
parse_signature: boolWhether to parse the PE Authenticode signature.
parse_exports: boolWhether to parse the PE Export Directory.
parse_imports: boolWhether to parse the PE Import Directory.
parse_rsrc: boolWhether to parse the PE resources tree.
parse_reloc: boolWhether to parse PE relocations.
parse_exceptions: boolWhether to parse in-depth exception metadata.
This option is disabled by default because it can introduce significant parsing overhead.
parse_arm64x_binary: boolWhether to parse nested ARM64X binaries.
This option is disabled by default because it can introduce significant parsing overhead.
Implementations
impl Config
impl Config
pub fn with_all_options() -> Self
pub fn with_all_options() -> Self
Configuration that enables all optional parsing features.