Struct Process
pub struct Process {}Expand description
This structure exposes Android-specific API for the current process.
Implementations
impl Process
impl Process
pub fn get_system_property(name: &str) -> Option<Property>
pub fn get_system_property(name: &str) -> Option<Property>
Return the Android system property with the given name
(e.g. ro.build.version.sdk) or None if the property does not exist.
pub fn properties() -> Properties ⓘ
pub fn properties() -> Properties ⓘ
Return an iterator over all the Android system properties.