lief::runtime::assembler

Function assemble_with_config

pub fn assemble_with_config(
    address: u64,
    asm: &str,
    config: &AssemblerConfig,
) -> Vec<u8>
Same as assemble but this function takes an extra AssemblerConfig that is used to configure the assembly engine: dialect, symbols definitions.