lief::runtime::host

Struct Host

pub struct Host {}
This structure represents the current host.

Implementations



impl Host

pub fn name() -> String

The machine hostname

pub fn home_dir() -> String

The user home dir (e.g. /home/romain or C:\Users\romain)

pub fn tmp_dir() -> String

Temporary directory.

This function looks at the environment variables to determine the suitable temp directory (e.g. TEMP, TMPDIR)

pub fn config_dir() -> String

The directory to store user-specific configuration

pub fn cache_dir() -> String

The directory where software should store their cache files (e.g. $HOME/.cache)