lief::runtime::memory

Struct Memory

pub struct Memory {}

Implementations



impl Memory

pub fn mmap(size: u64, flags: MmapFlags, permission: Perm) -> Option<Chunk>

Allocates a memory chunk through mmap-like function

pub fn munmap(chunk: &mut Chunk) -> Result<(), Error>

Deallocates a mmaped memory chunk

pub fn mprotect(chunk: &mut Chunk, perm: Perm) -> Result<(), Error>

Sets the permission of the given memory chunk

pub unsafe fn read<T>(addr: u64) -> T

Reads a value of type T from a raw memory address.

Safety

This function is unsafe and the caller must ensure that the operation is valid

pub unsafe fn write<T>(addr: u64, value: T)

Writes a value of type T to a raw memory address.

Safety

This function is unsafe and the caller must ensure that the operation is valid