lief::runtime::process

Struct Process

pub struct Process {}
This structure represents the current process and provides functions to query process-level information.

Implementations



impl Process

pub fn pid() -> i32

Get the Process ID of the current process.

pub fn tid() -> i32

Get the Thread ID of the current thread.

pub fn page_size() -> u32

Return the number of bytes in a memory page.

For instance:

  • 0x1000 (4096 bytes) for x86_64
  • 0x4000 (16384 bytes) for ARM64

pub fn arch() -> Arch

Target architecture of the current process

pub fn platform() -> Platform

Target platform of the current process

pub fn get_env(key: &str) -> Option<String>

Return the value of the environment variable key for the current process, or None if it is not set (or not valid Unicode).

pub fn get_envs() -> HashMap<String, String>

Return all the environment variables of the current process as a name -> value map.