Struct Process
pub struct Process {}Expand description
This structure represents the current process and provides functions to query process-level information.
Implementations
impl Process
impl Process
pub fn page_size() -> u32
pub fn page_size() -> u32
Return the number of bytes in a memory page.
For instance:
0x1000(4096 bytes) for x86_640x4000(16384 bytes) for ARM64