lief::runtime

Struct Region

pub struct Region { /* private fields */ }
A contiguous range of memory mapped in the current process.

Implementations



impl Region

pub fn name(&self) -> String

Name associated with the region: name/path of the module mapped at this address (e.g. libc.so.6) or the identifier of a region that is not backed by a file (e.g. [stack], [heap]).

It can be empty for anonymous regions.

pub fn addr(&self) -> u64

Address at which the region starts

pub fn size(&self) -> u64

Size of the region

pub fn end_addr(&self) -> u64

Address at which the region ends

pub fn contains(&self, addr: u64) -> bool

Whether the given address is within this region