Struct Fixup
pub struct Fixup<'a> { /* private fields */ }Expand description
A single relocation associated with a function-variant. It mirrors the
FunctionVariantFixups::InternalFixup structure used by dyld and
describes a slot that must be fixed up to point to the variant referenced by
Fixup::variant_index.
Implementations
impl Fixup<'_>
impl Fixup<'_>
pub fn seg_offset(&self) -> u32
pub fn seg_offset(&self) -> u32
Offset of the slot to fix up, relative to the segment designated by
Fixup::seg_index
pub fn variant_index(&self) -> u32
pub fn variant_index(&self) -> u32
Index of the FunctionVariants runtime table used to resolve the slot
pub fn pac_address(&self) -> bool
pub fn pac_address(&self) -> bool
Whether the pointer-authentication signature mixes the storage address (address diversity)
pub fn pac_diversity(&self) -> u16
pub fn pac_diversity(&self) -> u16
Pointer-authentication diversity (discriminator) of the slot
pub fn segment(&self) -> Option<Segment<'_>>
pub fn segment(&self) -> Option<Segment<'_>>
Segment referenced by Fixup::seg_index if it could be resolved