Struct Module
pub struct Module { /* private fields */ }Expand description
This structure represents a Windows-specific module
Implementations
impl Module
impl Module
pub fn handle(&self) -> *const c_void
pub fn handle(&self) -> *const c_void
Return the HMODULE handle as an opaque pointer.
Return a nullptr if the function fails or if the handler can’t be found
pub fn dlsym(&self, name: String) -> *const c_void
pub fn dlsym(&self, name: String) -> *const c_void
Resolve the symbol with the given name for the current module
pub fn parse_from_path(&self) -> Option<Binary>
pub fn parse_from_path(&self) -> Option<Binary>
Parse the PE module from its path on the filesystem
pub fn parse_from_path_with_config(
&self,
config: &ParserConfig,
) -> Option<Binary>
pub fn parse_from_path_with_config( &self, config: &ParserConfig, ) -> Option<Binary>
Parse the PE module from its path on the filesystem and given the parser configuration
pub fn parse_from_memory(&self) -> Option<Binary>
pub fn parse_from_memory(&self) -> Option<Binary>
Parse the PE module from memory
pub fn parse_from_memory_with_config(
&self,
config: &ParserConfig,
) -> Option<Binary>
pub fn parse_from_memory_with_config( &self, config: &ParserConfig, ) -> Option<Binary>
Parse the PE module from memory with the given configuration